"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loadExternal;
var _window = window,
    fetch = _window.fetch,
    AbortController = _window.AbortController;
/**
 * Loads the text contents of an external resource and invokes a callback with the result.
 * @param {String} url the URL of a resource to load
 * @param {Function} successCallback a callback function to invoke in case of success. Receives the result text.
 * @param {Function} errorCallback a callback function to invoke in case of error. Receives the error object.
 */

function loadExternal(url, successCallback) {
  var errorCallback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : console.warn;
  var controller = new AbortController();
  fetch(url, {
    method: 'get',
    signal: controller.signal
  }).then(function (response) {
    return response.text();
  }).then(function (text) {
    return successCallback(text);
  }).catch(function (error) {
    return errorCallback(error);
  });
  return function () {
    return controller.abort();
  };
}