const { fetch, AbortController } = window;

/**
 * Loads the text contents of an external resource and invokes a callback with the result.
 * @param {String} url the URL of a resource to load
 * @param {Function} successCallback a callback function to invoke in case of success. Receives the result text.
 * @param {Function} errorCallback a callback function to invoke in case of error. Receives the error object.
 */
export default function loadExternal(url, successCallback, errorCallback = console.warn) {
    const controller = new AbortController();
    fetch(url, {
        method: 'get',
        signal: controller.signal
    })
        .then(response => response.text())
        .then(text => successCallback(text))
        .catch(error => errorCallback(error));

    return () => controller.abort();
}
